PluginState

Enum PluginState 

pub enum PluginState {
    Persistent,
    Ephemeral,
    Scoped,
}
Lifecycle behavior of the plugin.

Variants



Persistent

Stays running between tasks.



Ephemeral

Spun up per task and torn down immediately after.



Scoped

Lives for the duration of an analysis scope (e.g. a batch).